@@ -9,7 +9,7 @@
 #define OPENCV_GAPI_CPU_CORE_API_HPP
 
 #include <opencv2/gapi/gkernel.hpp> // GKernelPackage
-#include "opencv2/gapi/own/exports.hpp" // GAPI_EXPORTS
+#include <opencv2/gapi/own/exports.hpp> // GAPI_EXPORTS
 
 namespace cv {
 namespace gapi {
